@@ -3,7 +3,7 @@ package VCS::CMSynergy;
 # Copyright (c) 2001-2015 argumentum GmbH
 # See COPYRIGHT section in VCS/CMSynergy.pod for usage and distribution rights.
 
-our $VERSION = '1.47';
+our $VERSION = '1.48';
 
 use 5.008_001;                          # i.e. v5.8.1
 use strict;
@@ -105,6 +105,8 @@ sub _start
     # prime web_mode early as possible
     $self->{web_mode} = 1 if $self->version >= 7.2;
 
+    my $role = delete $args{role};              # initial role
+
     foreach (qw( KeepSession UseCoprocess ))
     {
         $self->{$_} = delete $args{$_} if exists $args{$_};
@@ -168,7 +170,6 @@ sub _start
             database            => "-d",
             server              => "-s",
             password            => "-pw",
-            role                => "-r",
             user                => "-n",
         $self->web_mode ? () : (                # classic mode only
             ini_file            => undef,
@@ -228,6 +229,12 @@ sub _start
         INFO qq[started session "$out"];
     }
 
+    if (defined $role)
+    {
+        my ($rc, $out, $err) = $self->_set(role => $role);
+        return $self->set_error($err || $out) unless $rc == 0;
+    }
+
     # NOTE: Use of $CCM_INI_FILE fixes the annoying `Warning:
     # Security violation.  User JLUSER is not authorized to the
     # Continuus interface at ...'  when running on Windows.
@@ -1743,10 +1750,9 @@ sub ls_hashref
 sub ls_object
 {
     my $self = shift;
-    my ($file_spec) = validate(\@_, Optional[_FILE_SPEC]);
-    $file_spec = '.' unless defined $file_spec;
+    my ($file_spec, $keywords) = validate(\@_, _FILE_SPEC, _KEYWORDS);
 
-    return $self->_ls($file_spec, [], ROW_OBJECT);
+    return $self->_ls($file_spec, $keywords, ROW_OBJECT);
 }
 
 
